# Super SLURPy documentation

Super SLURPy is a Python version of Speech and Language Ultrasound Research
Package [SLURP](https://github.com/cathylaporte/SLURP). It provides a Python
API and a Python program. Latter is simply called `slurpy` and launches the
GUI.

## A note on the name(s)

The 'super' in the package/project name is there only to avoid a conflict with
a different project called `slurpy`. And maybe because it's kinda super to have
a Python version of SLURP. 

The commandline command is shorter to make life easier when using the program.
It's also fine to refer to the project by the shorter name, just as long as you
are aware that the long name is used on PyPi and thus for installing.
